# TimeTest
Checking execution time of python functions.
* `pip install timetest`

Now you can check execution time of your functions using:
* `averagetime_test(function_name, count_of_calls, *args, **kwagrs)` to see average time of execution
* `alltime_test(function_name, count_of_calls, *args, **kwagrs)` to see list of function executions times


execution time of quicksort:
![img1](https://github.com/Nimond/TimeTest/raw/master/images/4895EA67-9574-42A1-8F61-F1EBCF336365.png)

